@@ -11,18 +11,19 @@ class TIFFFormat : public ImageFormat {
         bool can_read() const { return true; }
         bool can_read_multi() const { return true; }
         bool can_write() const { return true; }
+        bool can_write_metadata() const { return true; }
 
-        std::auto_ptr<Image> read(byte_source* s, ImageFactory* f) {
+        std::auto_ptr<Image> read(byte_source* s, ImageFactory* f, const options_map& opts) {
             std::auto_ptr<image_list> pages = this->do_read(s, f, false);
             if (pages->size() != 1) throw ProgrammingError();
             std::vector<Image*> ims = pages->release();
             return std::auto_ptr<Image>(ims[0]);
         }
 
-        std::auto_ptr<image_list> read_multi(byte_source* s, ImageFactory* f) {
+        std::auto_ptr<image_list> read_multi(byte_source* s, ImageFactory* f, const options_map& opts) {
             return this->do_read(s, f, true);
         }
-        void write(Image* input, byte_sink* output);
+        void write(Image* input, byte_sink* output, const options_map& opts);
     private:
         std::auto_ptr<image_list> do_read(byte_source* s, ImageFactory* f, bool is_multi);
 };
