@@ -20,3 +20,9 @@ def test_formatstr():
     f = imread('./imread/tests/data/good', formatstr='png')
     assert f.shape == (2,2)
 
+
+def test_as_grey():
+    im = imread('imread/tests/data/star1.bmp', as_grey=False)
+    assert len(im.shape) == 3
+    im = imread('imread/tests/data/star1.bmp', as_grey=True)
+    assert len(im.shape) == 2
